@@ -61,14 +61,17 @@ quantile :: ExponentialDistribution -> Double -> Double
 quantile (ED l) p = -log (1 - p) / l
 {-# INLINE quantile #-}
 
--- | Create exponential distribution
+-- | Create an exponential distribution.
 exponential :: Double            -- ^ &#955; (scale) parameter.
             -> ExponentialDistribution
-exponential = ED
+exponential l
+  | l <= 0 = 
+    error $ "Statistics.Distribution.Exponential.exponential: scale parameter must be positive. Got " ++ show l
+  | otherwise = ED l
 {-# INLINE exponential #-}
 
 -- | Create exponential distribution from sample. No tests are made to
--- check whether it really exponential
+-- check whether it truly is exponential.
 exponentialFromSample :: Sample -> ExponentialDistribution
 exponentialFromSample = ED . S.mean
 {-# INLINE exponentialFromSample #-}
